==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SeriesLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesLayerDescription } from "./SeriesLayerDescription";
/**
 * @hidden
 */
export let SeriesLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class SeriesLayerDescriptionMetadata extends Base {
        static b(a) {
            if (SeriesLayerDescriptionMetadata.a == null) {
                SeriesLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SeriesLayerDescriptionMetadata.c(SeriesLayerDescriptionMetadata.a);
            }
            if (a.k(SeriesLayerDescriptionMetadata.a)) {
                return;
            }
            a.ab(SeriesLayerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ZIndex", "Number:double");
            a.item("PropertyOverlays", "Collection:SeriesLayerPropertyOverlay:SeriesLayerPropertyOverlayCollection:SeriesLayerPropertyOverlay");
        }
        static d(a) {
            SeriesLayerDescriptionMetadata.b(a);
            a.ad("SeriesLayer", () => new SeriesLayerDescription());
            a.ac("SeriesLayer", SeriesLayerDescriptionMetadata.a);
        }
    }
    SeriesLayerDescriptionMetadata.$t = markType(SeriesLayerDescriptionMetadata, 'SeriesLayerDescriptionMetadata');
    SeriesLayerDescriptionMetadata.a = null;
    return SeriesLayerDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SeriesLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesLayerDescription } from "./SeriesLayerDescription";
/**
 * @hidden
 */
export let SeriesLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class SeriesLayerDescriptionMetadata extends Base {
        static b(a) {
            if (SeriesLayerDescriptionMetadata.a == null) {
                SeriesLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SeriesLayerDescriptionMetadata.c(SeriesLayerDescriptionMetadata.a);
            }
            if (a.k(SeriesLayerDescriptionMetadata.a)) {
                return;
            }
            a.ac(SeriesLayerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ZIndex", "Number:double");
            a.item("PropertyOverlays", "Collection:SeriesLayerPropertyOverlay:SeriesLayerPropertyOverlayCollection:SeriesLayerPropertyOverlay");
        }
        static d(a) {
            SeriesLayerDescriptionMetadata.b(a);
            a.ae("SeriesLayer", () => new SeriesLayerDescription());
            a.ad("SeriesLayer", SeriesLayerDescriptionMetadata.a);
        }
    }
    SeriesLayerDescriptionMetadata.$t = markType(SeriesLayerDescriptionMetadata, 'SeriesLayerDescriptionMetadata');
    SeriesLayerDescriptionMetadata.a = null;
    return SeriesLayerDescriptionMetadata;
})();
